==> phpAdsNew-2.0.8.tar.gz: phpAdsNew-2.0.8/language/english/userlog.lang.php <==
<?php // $Revision: 2.0.2.3 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2006 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


// Set translation strings

$GLOBALS['strDeliveryEngine']				= "Delivery Engine";
$GLOBALS['strMaintenance']					= "Maintenance";
$GLOBALS['strAdministrator']				= "Administrator";


$GLOBALS['strUserlog'] = array (
	phpAds_actionAdvertiserReportMailed 	=> "Report for advertiser {id} send by e-mail",
	phpAds_actionPublisherReportMailed 		=> "Report for publisher {id} send by e-mail",
	phpAds_actionWarningMailed				=> "Deactivation warning for campaign {id} send by e-mail",
	phpAds_actionDeactivationMailed			=> "Deactivation notification for campaign {id} send by e-mail",
	phpAds_actionPriorityCalculation		=> "Priority recalculated",
	phpAds_actionPriorityAutoTargeting		=> "Campaign targets recalculated",
	phpAds_actionDeactiveCampaign			=> "Campaign {id} deactivated",
	phpAds_actionActiveCampaign				=> "Campaign {id} activated",
	phpAds_actionAutoClean					=> "Auto clean of database"
);

?>

==> phpAdsNew-2.0.9-pr1.tar.gz: phpAdsNew-2.0.9-pr1/language/english/userlog.lang.php <==
<?php // $Revision: 2.0.2.5 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2006 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


// Set translation strings

$GLOBALS['strDeliveryEngine']				= "Delivery Engine";
$GLOBALS['strMaintenance']					= "Maintenance";
$GLOBALS['strAdministrator']				= "Administrator";


$GLOBALS['strUserlog'] = array (
	phpAds_actionAdvertiserReportMailed 	=> "Report for advertiser {id} sent by e-mail",
	phpAds_actionPublisherReportMailed 		=> "Report for publisher {id} sent by e-mail",
	phpAds_actionWarningMailed				=> "Deactivation warning for campaign {id} sent by e-mail",
	phpAds_actionDeactivationMailed			=> "Deactivation notification for campaign {id} sent by e-mail",
	phpAds_actionPriorityCalculation		=> "Priority recalculated",
	phpAds_actionPriorityAutoTargeting		=> "Campaign targets recalculated",
	phpAds_actionDeactiveCampaign			=> "Campaign {id} deactivated",
	phpAds_actionActiveCampaign				=> "Campaign {id} activated",
	phpAds_actionAutoClean					=> "Auto clean of database",
	phpAds_actionGeotargeting				=> "Geotargeting configuration update"
);

?>
